@@ -8,7 +8,7 @@ __docformat__ = "restructuredtext en"
 
 from logilab.mtconverter import xml_escape
 
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 from cubes.tracker.views import doap as doap_tracker
 
